<?php

namespace Intergo\MessageClient;

use Intergo\BaseClient\Client;
use Intergo\BaseClient\Responses\BaseResponseInterface;

class AbstractMessageService
{
    protected MessageClient $client;

    /**
     * AbstractMessageService constructor.
     *
     * @param $baseUrl
     * @param $traceId
     */
    public function __construct($baseUrl, $traceId)
    {
        $this->client = new MessageClient($baseUrl, $traceId);
    }

    /**
     * @param string $user_id
     * @param array $settings
     * @return BaseResponseInterface
     */
    public function updateUserSettingsV2(string $user_id, array $settings)
    {
        return $this->client->execute(__FUNCTION__, compact('user_id'), $settings);
    }

    /**
     * @param string $user_id
     * @param array $viber_settings
     * @param array $viber_prices
     * @return BaseResponseInterface
     */
    public function updateViberSettings(string $user_id, array $viber_settings, array $viber_prices)
    {
        return $this->client->execute(__FUNCTION__, compact('user_id'), compact('viber_settings', 'viber_prices'));
    }

    /**
     * @param string $user_id
     * @return BaseResponseInterface
     */
    public function getUserSettings(string $user_id)
    {
        return $this->client->execute(__FUNCTION__, compact('user_id'), []);
    }

    /**
     * @param string $user_id
     * @return BaseResponseInterface
     */
    public function invalidateUserLists(string $user_id)
    {
        return $this->client->execute(__FUNCTION__, compact('user_id'), []);
    }

    /**
     * @param $id
     * @param $data
     * @return BaseResponseInterface
     */
    public function updateNetwork($id, $data)
    {
        extract($data);
        unset($data);
        return $this->client->execute(__FUNCTION__, compact('id'), get_defined_vars());
    }

    /**
     * @param $message_id
     * @return BaseResponseInterface
     */
    public function updateStatusMessageFromProvider($message_id): BaseResponseInterface
    {
        return $this->client->execute(__FUNCTION__, compact('message_id'), get_defined_vars());
    }

    /**
     * @param $from
     * @param $to
     * @param $provider_id
     * @param $user_id
     * @return BaseResponseInterface
     */
    public function updateStatusMessageMassFromProvider($from, $to, $provider_id, $user_id, $bearerToken): BaseResponseInterface
    {
        return $this->client->executeAuth(__FUNCTION__, $bearerToken, [],
            compact("from", "to", "provider_id", "user_id"));
    }

}